==> react-form-builder-5.11.0.tgz: package/lib/FieldSet/index.js <==
import { isValidElement } from 'react';
import PropTypes from 'prop-types';
import { field } from '../prop-types';
import ProxyField from '../ProxyField';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var baseClass = 'sui-FormBuilder-FieldSet';

var FieldSet = function FieldSet(_ref) {
  var fieldset = _ref.fieldset,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      fieldSize = _ref.fieldSize,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;

  if (fieldset.hidden) {
    return null;
  }

  var fieldsetProps = {
    id: fieldset.id,
    name: fieldset.id,
    label: fieldset.label || '',
    fields: fieldset.fields
  };
  var rendererResponse = renderer({
    id: fieldset.id,
    innerProps: fieldsetProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse;
  var label = (rendererResponse == null ? void 0 : rendererResponse.label) || fieldset.label;
  var icon = (rendererResponse == null ? void 0 : rendererResponse.icon) || fieldset.icon;
  var fields = (rendererResponse == null ? void 0 : rendererResponse.fields) || fieldset.fields || [];
  return /*#__PURE__*/_jsxs("fieldset", {
    className: baseClass + " " + baseClass + "-" + fieldset.id,
    children: [label && /*#__PURE__*/_jsxs("legend", {
      children: [icon && /*#__PURE__*/_jsx("span", {
        children: icon
      }), /*#__PURE__*/_jsx("span", {
        children: label
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: baseClass + "Container",
      children: fields.map(function (field, index) {
        var _field$tabIndex;

        var fieldTabIndex = (_field$tabIndex = field.tabIndex) != null ? _field$tabIndex : tabIndex + index * 0.1;
        return /*#__PURE__*/_jsx(ProxyField, {
          onChange: onChange,
          onFocus: onFocus,
          onBlur: onBlur,
          field: field,
          tabIndex: fieldTabIndex,
          fieldSize: fieldSize,
          errors: errors,
          alerts: alerts,
          renderer: renderer
        }, field.id);
      })
    })]
  });
};

FieldSet.displayName = 'FieldSet';
export default FieldSet;

==> react-form-builder-5.13.0.tgz: package/lib/FieldSet/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement } from 'react';
import PropTypes from 'prop-types';
import { field } from '../prop-types';
import ProxyField from '../ProxyField';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var baseClass = 'sui-FormBuilder-FieldSet';

var FieldSet = function FieldSet(_ref) {
  var fieldset = _ref.fieldset,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      fieldSize = _ref.fieldSize,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;

  if (fieldset.hidden) {
    return null;
  }

  var innerProps = fieldset.fields.map(function (props, index) {
    var _field$tabIndex;

    var fieldTabIndex = (_field$tabIndex = field.tabIndex) != null ? _field$tabIndex : tabIndex + index * 0.1;
    return _extends({}, props, {
      tabIndex: fieldTabIndex,
      onChange: onChange,
      onFocus: onFocus,
      onBlur: onBlur,
      fieldSize: fieldSize,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  });
  var rendererResponse = renderer({
    id: fieldset.id,
    name: fieldset.id,
    label: fieldset.label || '',
    fields: fieldset.fields,
    innerProps: innerProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse;
  var label = (rendererResponse == null ? void 0 : rendererResponse.label) || fieldset.label;
  var icon = (rendererResponse == null ? void 0 : rendererResponse.icon) || fieldset.icon;
  var fields = (rendererResponse == null ? void 0 : rendererResponse.fields) || fieldset.fields || [];
  return /*#__PURE__*/_jsxs("fieldset", {
    className: baseClass + " " + baseClass + "-" + fieldset.id,
    children: [label && /*#__PURE__*/_jsxs("legend", {
      children: [icon && /*#__PURE__*/_jsx("span", {
        children: icon
      }), /*#__PURE__*/_jsx("span", {
        children: label
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: baseClass + "Container",
      children: fields.map(function (field, index) {
        var _field$tabIndex2;

        var fieldTabIndex = (_field$tabIndex2 = field.tabIndex) != null ? _field$tabIndex2 : tabIndex + index * 0.1;
        return /*#__PURE__*/_jsx(ProxyField, {
          onChange: onChange,
          onFocus: onFocus,
          onBlur: onBlur,
          field: field,
          tabIndex: fieldTabIndex,
          fieldSize: fieldSize,
          errors: errors,
          alerts: alerts,
          renderer: renderer
        }, field.id);
      })
    })]
  });
};

FieldSet.displayName = 'FieldSet';
export default FieldSet;
